Documentation
¶
Index ¶
- Constants
- Variables
- func BsSysLogPort() int
- func SafeAttachWaitContainer(p DockerProvisioner, opts docker.AttachToContainerOptions) (int, error)
- type AppLocker
- type Container
- func (c *Container) Address() *url.URL
- func (c *Container) AsUnit(a provision.App) provision.Unit
- func (c *Container) Available() bool
- func (c *Container) Commit(p DockerProvisioner, writer io.Writer) (string, error)
- func (c *Container) Create(args *CreateArgs) error
- func (c *Container) Exec(p DockerProvisioner, stdout, stderr io.Writer, cmd string, args ...string) error
- func (c *Container) Logs(p DockerProvisioner, w io.Writer) (int, error)
- func (c *Container) NetworkInfo(p DockerProvisioner) (NetworkInfo, error)
- func (c *Container) Remove(p DockerProvisioner) error
- func (c *Container) SetImage(p DockerProvisioner, imageId string) error
- func (c *Container) SetStatus(p DockerProvisioner, status provision.Status, updateDB bool) error
- func (c *Container) Shell(p DockerProvisioner, stdin io.Reader, stdout, stderr io.Writer, pty Pty) error
- func (c *Container) ShortID() string
- func (c *Container) Sleep(p DockerProvisioner) error
- func (c *Container) Start(args *StartArgs) error
- func (c *Container) Stop(p DockerProvisioner) error
- type CreateArgs
- type DockerLog
- type DockerProvisioner
- type NetworkInfo
- type Pty
- type StartArgs
Constants ¶
const (
DockerLogDriverConfig = "log-driver"
)
Variables ¶
var ( ErrLogDriverMandatory = errors.New("log-driver is mandatory") ErrLogDriverBSNoParams = errors.New("bs log-driver do not accept log-opts, please use bs-env-set to configure it.") )
Functions ¶
func BsSysLogPort ¶
func BsSysLogPort() int
func SafeAttachWaitContainer ¶
func SafeAttachWaitContainer(p DockerProvisioner, opts docker.AttachToContainerOptions) (int, error)
Types ¶
type Container ¶
type Container struct {
MongoID bson.ObjectId `bson:"_id,omitempty"`
ID string
AppName string
ProcessName string
Type string
IP string
HostAddr string
HostPort string
PrivateKey string
Status string
Version string
Image string
Name string
User string
BuildingImage string
LastStatusUpdate time.Time
LastSuccessStatusUpdate time.Time
LockedUntil time.Time
Routable bool `bson:"-"`
}
func (*Container) Commit ¶
Commits commits the container, creating an image in Docker. It then returns the image identifier for usage in future container creation.
func (*Container) Create ¶
func (c *Container) Create(args *CreateArgs) error
func (*Container) NetworkInfo ¶
func (c *Container) NetworkInfo(p DockerProvisioner) (NetworkInfo, error)
func (*Container) Remove ¶
func (c *Container) Remove(p DockerProvisioner) error
func (*Container) SetImage ¶
func (c *Container) SetImage(p DockerProvisioner, imageId string) error
func (*Container) Sleep ¶
func (c *Container) Sleep(p DockerProvisioner) error
func (*Container) Stop ¶
func (c *Container) Stop(p DockerProvisioner) error
type CreateArgs ¶
type DockerLog ¶
type DockerLog struct {
// contains filtered or unexported fields
}
type DockerProvisioner ¶
type NetworkInfo ¶
Click to show internal directories.
Click to hide internal directories.